//+------------------------------------------------------------------+
//|                                                  Custom MACD.mq4 |
//|                      Copyright  2004, MetaQuotes Software Corp. |
//|                                       http://www.metaquotes.net/ |
//+------------------------------------------------------------------+
// Time frame enumeration
// Constant    Value Description 
// PERIOD_M1   1     1 minute. 
// PERIOD_M5   5     5 minutes. 
// PERIOD_M15  15    15 minutes. 
// PERIOD_M30  30    30 minutes. 
// PERIOD_H1   60    1 hour. 
// PERIOD_H4   240   4 hour. 
// PERIOD_D1   1440  Daily. 
// PERIOD_W1   10080 Weekly. 
// PERIOD_MN1  43200 Monthly. 
// 0 (zero) 0 Time frame used on the chart. 
//
// Moving Average method enumeration
// Constant    Value    Description 
// MODE_SMA    0        Simple moving average, 
// MODE_EMA    1        Exponential moving average, 
// MODE_SMMA   2        Smoothed moving average, 
// MODE_LWMA   3        Linear weighted moving average. 
//
// Applied price enumeration
// Constant       Value    Description 
// PRICE_CLOSE    0        Close price. 
// PRICE_OPEN     1        Open price. 
// PRICE_HIGH     2        High price. 
// PRICE_LOW      3        Low price. 
// PRICE_MEDIAN   4        Median price, (high+low)/2. 
// PRICE_TYPICAL  5        Typical price, (high+low+close)/3. 
// PRICE_WEIGHTED 6        Weighted close price, (high+low+close+close)/4. 

#property  copyright "Copyright  2004, MetaQuotes Software Corp."
#property  link      "http://www.metaquotes.net/"

//---- indicator settings
#property  indicator_chart_window
#property  indicator_buffers 2
#property  indicator_color1  Red
#property  indicator_color2  Red

//---- indicator parameters
extern int Time_Period = PERIOD_H4;

extern int Fast_MA = 8;
extern int Fast_Type = MODE_SMA;
extern int Fast_Applied_Price = PRICE_CLOSE;

extern int Slow_MA = 55;
extern int Slow_Type = MODE_SMA;
extern int Slow_Applied_Price = PRICE_MEDIAN;

extern double Zone = 50;

//---- indicator buffers
double     ind_buffer1[];
double     ind_buffer2[];

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- drawing settings
   SetIndexStyle(0,DRAW_LINE,STYLE_DOT);
   SetIndexStyle(1,DRAW_LINE,STYLE_DOT);
   SetIndexDrawBegin(1,Slow_MA);
   IndicatorDigits(MarketInfo(Symbol(),MODE_DIGITS)+1);

//---- indicator buffers mapping
   if(!SetIndexBuffer(0,ind_buffer1) && !SetIndexBuffer(1,ind_buffer2))
      Print("cannot set indicator buffers!");

//---- name for DataWindow and indicator subwindow label
   IndicatorShortName("ZONE LINES(" + Time_Period + "," + Fast_MA + ")");
   SetIndexLabel(0,"ZONE_LINES");

//---- initialization done
   return(0);
  }

//+------------------------------------------------------------------+
//| Moving Averages Convergence/Divergence                           |
//+------------------------------------------------------------------+
int start()
  {
   int limit;
   int counted_bars=IndicatorCounted();
   double Curr_Fast_MA;
   double Curr_Slow_MA;
   double ZoneDigits;
   
   if (Digits == 2 )
   {
      ZoneDigits = Zone/100;
   }
   else if (Digits == 4)
   {
      ZoneDigits = Zone/10000;
   }
   
//---- check for possible errors
   if(counted_bars<0) return(-1);

//---- last counted bar will be recounted
   if(counted_bars>0) counted_bars--;
   limit=Bars-counted_bars;

   Curr_Fast_MA = iMA(NULL,0,Fast_MA,0,Fast_Type,Fast_Applied_Price,0);
   Curr_Slow_MA = iMA(NULL,0,Slow_MA,0,Slow_Type,Slow_Applied_Price,0);
             
//---- are ma's & price all within the zone?
   if (Curr_Fast_MA - Curr_Slow_MA <= ZoneDigits)
   {
//---- macd counted in the 1-st buffer
      for(int i=0; i<=Fast_MA; i++)
         {
            if (Curr_Fast_MA > Curr_Slow_MA)
            {
               ind_buffer1[i]=Curr_Slow_MA + ZoneDigits;
               ind_buffer2[i]=Curr_Fast_MA - ZoneDigits;
               
               
            }
            else
            {
               ind_buffer1[i]=Curr_Fast_MA - ZoneDigits;
               ind_buffer2[i]=Curr_Slow_MA + ZoneDigits;
            }
         }
   }

//---- done
   return(0);
  }