//+------------------------------------------------------------------+
//|                                                  Custom MACD.mq4 |
//|                      Copyright  2004, MetaQuotes Software Corp. |
//|                                       http://www.metaquotes.net/ |
//+------------------------------------------------------------------+
// Time frame enumeration
// Constant    Value Description 
// PERIOD_M1   1     1 minute. 
// PERIOD_M5   5     5 minutes. 
// PERIOD_M15  15    15 minutes. 
// PERIOD_M30  30    30 minutes. 
// PERIOD_H1   60    1 hour. 
// PERIOD_H4   240   4 hour. 
// PERIOD_D1   1440  Daily. 
// PERIOD_W1   10080 Weekly. 
// PERIOD_MN1  43200 Monthly. 
// 0 (zero) 0 Time frame used on the chart. 
//
// Moving Average method enumeration
// Constant    Value    Description 
// MODE_SMA    0        Simple moving average, 
// MODE_EMA    1        Exponential moving average, 
// MODE_SMMA   2        Smoothed moving average, 
// MODE_LWMA   3        Linear weighted moving average. 
//
// Applied price enumeration
// Constant       Value    Description 
// PRICE_CLOSE    0        Close price. 
// PRICE_OPEN     1        Open price. 
// PRICE_HIGH     2        High price. 
// PRICE_LOW      3        Low price. 
// PRICE_MEDIAN   4        Median price, (high+low)/2. 
// PRICE_TYPICAL  5        Typical price, (high+low+close)/3. 
// PRICE_WEIGHTED 6        Weighted close price, (high+low+close+close)/4. 

#property  copyright "Copyright  2004, MetaQuotes Software Corp."
#property  link      "http://www.metaquotes.net/"

//---- indicator settings
#property  indicator_chart_window
#property  indicator_buffers 1
#property  indicator_color1  Silver

//---- indicator parameters
extern int Time_Period = PERIOD_H4;

extern int Fast_MA = 8;
extern int Fast_Type = MODE_SMA;
extern int Fast_Applied_Price = PRICE_CLOSE;

//---- indicator buffers
double     ind_buffer1[];

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- drawing settings
   SetIndexStyle(0,DRAW_LINE,STYLE_SOLID);
   SetIndexDrawBegin(1,Fast_MA);
   IndicatorDigits(MarketInfo(Symbol(),MODE_DIGITS)+1);

//---- indicator buffers mapping
   if(!SetIndexBuffer(0,ind_buffer1))
      Print("cannot set indicator buffers!");

//---- name for DataWindow and indicator subwindow label
   IndicatorShortName("SMA LINE(" + Time_Period + "," + Fast_MA + ")");
   SetIndexLabel(0,"SMA_LINE");

//---- initialization done
   return(0);
  }

//+------------------------------------------------------------------+
//| Moving Averages Convergence/Divergence                           |
//+------------------------------------------------------------------+
int start()
  {
   int limit;
   int counted_bars=IndicatorCounted();

//---- check for possible errors
   if(counted_bars<0) return(-1);

//---- last counted bar will be recounted
   if(counted_bars>0) counted_bars--;
   limit=Bars-counted_bars;

//---- macd counted in the 1-st buffer
   for(int i=0; i<=Fast_MA; i++)
      ind_buffer1[i]= Close[Fast_MA];

//---- done
   return(0);
  }